==> pip_services3_rpc-3.0.3.tar.gz: pip_services3_rpc-3.0.3/pip_services3_rpc/services/HttpResponseDetector.py <==
# -*- coding: utf-8 -*-


import re
import json

from pip_services3_commons.convert.RecursiveMapConverter import RecursiveMapConverter


class HttpResponseDetector:
    """
    Helper class that retrieves parameters from HTTP requests.
    """

    @staticmethod
    def detect_platform(req):
        """
        Detects the platform (using "user-agent") from which the given HTTP request was made.

        :param req: an HTTP request to process.
        :return: the detected platform and version. Detectable platforms: "mobile", "iphone",
        "ipad",  "macosx", "android",  "webos", "mac", "windows". Otherwise - "unknown" will
        be returned.
        """
        ua = req.headers['user-agent']
        if re.search(r'mobile', ua, re.I):
            return 'mobile'
        if re.search(r'like Mac OS X', ua):
            version = re.sub(r'_', '.', re.search(r'CPU( iPhone)? OS ([0-9._]+) like Mac OS X', ua)[2])
            if re.search(r'iPhone', ua):
                return 'iphone ' + version
            if re.search(r'iPad', ua):
                return 'ipad ' + version
            return 'macosx ' + version
        if re.search(r'Android', ua):
            version = re.search(r'Android ([0-9.]+)[);]', ua)[1]
            return 'android ' + version
        if re.search(r'webOS/', ua):
            version = re.search(r'webOS/([0-9.]+)[);]', ua)[1]
            return 'webos ' + version
        if re.search(r'(Intel|PPC) Mac OS X', ua):
            version = re.sub(r'_', '.', re.search(r'(Intel|PPC) Mac OS X ?([0-9._]*)[);]', ua)[2])
            return 'mac ' + version

        if re.search(r'Windows NT', ua):
            version = re.search(r'Windows NT ([0-9._]+)[);]', ua)[1]
            return 'windows ' + version
        else:
            return 'unknown'

    @staticmethod
    def detect_browser(req):
        """
        Detects the browser (using "user-agent") from which the given HTTP request was made.

        :param req: an HTTP request to process.
        :return: the detected browser. Detectable browsers: "chrome", "msie", "firefox",
        "safari". Otherwise - "unknown" will be returned.
        """
        ua = req.headers['user-agent']
        if re.search(r'chrome', ua, re.I):
            return 'chrome'
        if re.search(r'msie', ua, re.I):
            return 'msie'
        if re.search(r'firefox', ua, re.I):
            return 'firefox'
        if re.search(r'safari', ua, re.I):
            return 'safari'

        return ua or 'unknown'

    @staticmethod
    def detect_address(req):
        """
        Detects the IP address from which the given HTTP request was received.

        :param req: an HTTP request to process.
        :return: the detected IP address (without a port). If no IP is detected -
        <code>null</code> will be returned.
        """
        ip = None
        if req.get_header('x-forwarded-for'):
            ip = req.get_header('x-forwarded-for').split(',')[0]

        if ip is None and 'connection' in json.loads(req.json).keys():
            try:
                ip = json.loads(req.json)['connection']['remoteAddress']
            except KeyError:
                try:
                    ip = json.loads(req.json)['connection']['socket']['remoteAddress']
                except KeyError:
                    pass

        if ip is None:
            try:
                ip = json.loads(req.json)['socket']['remoteAddress']
            except KeyError:
                pass

        if ip is not None:
            ip = str(ip)
            index = ip.find(':')
            if index > 0:
                ip = ip[0:index]

        return ip

    @staticmethod
    def detect_server_host(req):
        """
        Detects the host name of the request's destination server.

        :param req: an HTTP request to process.
        :return: the destination server's host name.
        """
        return '' + req.get_header('host').split(':')[0]

    @staticmethod
    def detect_server_port(req):
        """
        Detects the request's destination port number.

        :param req: an HTTP request to process.
        :return: the detected port number or <code>80</code> (if none are detected).
        """
        return req.get_header('host').split(':')[1]

==> pip_services3_rpc-3.1.5.tar.gz: pip_services3_rpc-3.1.5/pip_services3_rpc/services/HttpResponseDetector.py <==
# -*- coding: utf-8 -*-


import re
import json

from pip_services3_commons.convert.RecursiveMapConverter import RecursiveMapConverter


class HttpResponseDetector:
    """
    Helper class that retrieves parameters from HTTP requests.
    """

    @staticmethod
    def detect_platform(req):
        """
        Detects the platform (using "user-agent") from which the given HTTP request was made.

        :param req: an HTTP request to process.
        :return: the detected platform and version. Detectable platforms: "mobile", "iphone",
        "ipad",  "macosx", "android",  "webos", "mac", "windows". Otherwise - "unknown" will
        be returned.
        """
        ua = req.headers['user-agent']
        if re.search(r'mobile', ua, re.I):
            return 'mobile'
        if re.search(r'like Mac OS X', ua):
            version = re.sub(r'_', '.', re.search(r'CPU( iPhone)? OS ([0-9._]+) like Mac OS X', ua)[2])
            if re.search(r'iPhone', ua):
                return 'iphone ' + version
            if re.search(r'iPad', ua):
                return 'ipad ' + version
            return 'macosx ' + version
        if re.search(r'Android', ua):
            version = re.search(r'Android ([0-9.]+)[);]', ua)[1]
            return 'android ' + version
        if re.search(r'webOS/', ua):
            version = re.search(r'webOS/([0-9.]+)[);]', ua)[1]
            return 'webos ' + version
        if re.search(r'(Intel|PPC) Mac OS X', ua):
            version = re.sub(r'_', '.', re.search(r'(Intel|PPC) Mac OS X ?([0-9._]*)[);]', ua)[2])
            return 'mac ' + version

        if re.search(r'Windows NT', ua):
            version = re.search(r'Windows NT ([0-9._]+)[);]', ua)[1]
            return 'windows ' + version
        else:
            return 'unknown'

    @staticmethod
    def detect_browser(req):
        """
        Detects the browser (using "user-agent") from which the given HTTP request was made.

        :param req: an HTTP request to process.
        :return: the detected browser. Detectable browsers: "chrome", "msie", "firefox",
        "safari". Otherwise - "unknown" will be returned.
        """
        ua = req.headers['user-agent']
        if re.search(r'chrome', ua, re.I):
            return 'chrome'
        if re.search(r'msie', ua, re.I):
            return 'msie'
        if re.search(r'firefox', ua, re.I):
            return 'firefox'
        if re.search(r'safari', ua, re.I):
            return 'safari'

        return ua or 'unknown'

    @staticmethod
    def detect_address(req):
        """
        Detects the IP address from which the given HTTP request was received.

        :param req: an HTTP request to process.
        :return: the detected IP address (without a port). If no IP is detected -
        **None** will be returned.
        """
        ip = None
        if req.get_header('x-forwarded-for'):
            ip = req.get_header('x-forwarded-for').split(',')[0]

        if ip is None and 'connection' in json.loads(req.json).keys():
            try:
                ip = json.loads(req.json)['connection']['remoteAddress']
            except KeyError:
                try:
                    ip = json.loads(req.json)['connection']['socket']['remoteAddress']
                except KeyError:
                    pass

        if ip is None:
            try:
                ip = json.loads(req.json)['socket']['remoteAddress']
            except KeyError:
                pass

        if ip is not None:
            ip = str(ip)
            index = ip.find(':')
            if index > 0:
                ip = ip[0:index]

        return ip

    @staticmethod
    def detect_server_host(req):
        """
        Detects the host name of the request's destination server.

        :param req: an HTTP request to process.
        :return: the destination server's host name.
        """
        return '' + req.get_header('host').split(':')[0]

    @staticmethod
    def detect_server_port(req):
        """
        Detects the request's destination port number.

        :param req: an HTTP request to process.
        :return: the detected port number or **80** (if none are detected).
        """
        return req.get_header('host').split(':')[1]
